#include "ADO.au3"
#Tidy_Parameters=/sort_funcs /reel
#AutoIt3Wrapper_Au3Check_Parameters=-d -w 1 -w 2 -w 3 -w- 4 -w 5 -w 6 -w 7

#include <Array.au3>
#include <MsgBoxConstants.au3>
#include <AutoItConstants.au3>

; SetUP internal ADO.au3 UDF COMError Handler
_ADO_ComErrorHandler_UserFunction(_ADO_COMErrorHandler)

_Example_MSAccess()
_Example_MSExcel()
_Example_MSSQL()
_Example_PostgreSQL()

Func _Example_MSAccess()

	Local $sMDB_FileFullPath = 'Here put FileFullPath to your Access File'
	Local $sDriver = Default
	Local $sUser = Default
	Local $sPassword = Default

	Local $sConnectionString = _ADO_ConnectionString_Access($sMDB_FileFullPath, $sUser, $sPassword, $sDriver)

	_Example_1_RecordsetToConsole($sConnectionString, "Select * from SOME_TABLE")
	_Example_2_RecordsetDisplay($sConnectionString, "Select * from SOME_TABLE")
	_Example_3_ConnectionProperties($sConnectionString)

EndFunc    ;==>_Example_MSAccess

Func _Example_MSExcel()

	Local $sFileFullPath = Default ; Here put FileFullPath to your Access File or use Default to open FileOpenDialog
	Local $sProvider = Default
	Local $sExtProperties = Default
	Local $HDR = Default
	Local $IMEX = Default

	Local $sConnectionString = _ADO_ConnectionString_Excel($sFileFullPath = Default, $sProvider , $sExtProperties , $HDR , $IMEX)

	_Example_1_RecordsetToConsole($sConnectionString, "select * from [Sheet1$]")
	_Example_2_RecordsetDisplay($sConnectionString, "select * from [Sheet1$]")
	_Example_3_ConnectionProperties($sConnectionString)

EndFunc    ;==>_Example_MSAccess

Func _Example_MSSQL()

	Local $sDriver = 'SQL Server'
	Local $sDatabase = 'YourBASENAME'
	Local $sServer = 'localhost/SQLExpress'
	Local $sUser = 'YourUserName'
	Local $sPassword = 'YourPassword'

	Local $sConnectionString = 'DRIVER={' & $sDriver & '};SERVER=' & $sServer & ';DATABASE=' & $sDatabase & ';UID=' & $sUser & ';PWD=' & $sPassword & ';'

	_Example_1_RecordsetToConsole($sConnectionString, "Select * from SOME_TABLE")
	_Example_2_RecordsetDisplay($sConnectionString, "Select * from SOME_TABLE")
	_Example_3_ConnectionProperties($sConnectionString)

	_Example_4_MSSQL($sServer, $sDatabase, $sUser, $sPassword, "Select * from SOME_TABLE")

EndFunc    ;==>_Example_MSSQL

Func _Example_PostgreSQL()
	Local $sDSN = 'PostgreSQL35W'
	Local $sDatabase = 'YourBASENAME'
	Local $sServer = ''
	Local $sPort = ''
	Local $sUser = 'YourUserName'
	Local $sPassword = 'YourPassword'

	Local $sConnectionString = 'DSN=' & $sDSN & ';DATABASE=' & $sDatabase & ';SERVER=' & $sServer & ';PORT=' & $sPort & ';UID=' & $sUser & ';PWD=' & $sPassword & ';'

	_Example_1_RecordsetToConsole($sConnectionString, "Select * from SOME_TABLE")
	_Example_2_RecordsetDisplay($sConnectionString, "Select * from SOME_TABLE")
	_Example_3_ConnectionProperties($sConnectionString)

EndFunc    ;==>_Example_PostgreSQL
#Region Common / internal

Func _Example_1_RecordsetToConsole($sConnectionString, $sQUERY)

	; Create connection object
	Local $oConnection = _ADO_Connection_Create()

	; Open connection with $sConnectionString
	_ADO_Connection_OpenConString($oConnection, $sConnectionString)
	If @error Then Return SetError(@error, @extended, $ADO_RET_FAILURE)

	; Executing some query
	Local $oRecordset = _ADO_Execute($oConnection, $sQUERY)

	; Get recordset to array of arrays (Conent and ColumnNames)
	Local $aRecordsetArray = _ADO_Recordset_ToArray($oRecordset, False)

	; Get inner array - only conent of Recordset
	Local $aRecordsetContent = _ADO_RecordsetArray_GetContent($aRecordsetArray)

	; Go through the array variable (Recorset Conent)
	Local $iColumn_count = UBound($aRecordsetContent, $UBOUND_COLUMNS)
	For $iRecord_idx = 0 To UBound($aRecordsetContent) - 1
		ConsoleWrite('==================================================================' & @CRLF)
		For $iColumn_idx = 0 To $iColumn_count - 1
			ConsoleWrite($aRecordsetContent[$iRecord_idx][$iColumn_idx] & @CRLF)
		Next
	Next

	; Clean Up
	$oRecordset = Null
	_ADO_Connection_Close($oConnection)
	$oConnection = Null

EndFunc    ;==>_Example_1_RecordsetToConsole

Func _Example_2_RecordsetDisplay($sConnectionString, $sQUERY)

	; Create connection object
	Local $oConnection = _ADO_Connection_Create()

	; Open connection with $sConnectionString
	_ADO_Connection_OpenConString($oConnection, $sConnectionString)
	If @error Then Return SetError(@error, @extended, $ADO_RET_FAILURE)

	; Executing some query directly to Array of Arrays (instead to $oRecordset)
	Local $aRecordset = _ADO_Execute($oConnection, $sQUERY, True)

	; Clean Up
	_ADO_Connection_Close($oConnection)
	$oConnection = Null

	; Display Array Content with column names as headers
	_ADO_REcordset_Display($aRecordset, 'Recordset content')

EndFunc    ;==>_Example_2_RecordsetDisplay

Func _Example_3_ConnectionProperties($sConnectionString)

	; Create connection object
	Local $oConnection = _ADO_Connection_Create()

	; Open connection with $sConnectionString
	_ADO_Connection_OpenConString($oConnection, $sConnectionString)
	If @error Then Return SetError(@error, @extended, $ADO_RET_FAILURE)

	; Get all connection properties to Array
	Local $aProperties = _ADO_Connection_PropertiesToArray($oConnection)

	; Clean Up
	_ADO_Connection_Close($oConnection)
	$oConnection = Null

	; Show connection properties
	_ArrayDisplay($aProperties, "ADO connection - List of properties", "", 0, Default, "Name|Type|Value|Attributes")

EndFunc    ;==>_Example_3_ConnectionProperties

Func _Example_4_MSSQL($sServer, $sDatabase, $sUser, $sPassword, $sQUERY)

	; Create connection object
	Local $oConnection = _ADO_Connection_Create()

	; Open connection with $sConnectionString
	_ADO_Connection_OpenMSSQL($oConnection, $sServer, $sDatabase, $sUser, $sPassword, 'YourAppName', @ComputerName & '_' & 'YourProgram_UID')
	If @error Then Return SetError(@error, @extended, $ADO_RET_FAILURE)

	; Executing some query directly to Array of Arrays (instead to $oRecordset)
	Local $aRecordset = _ADO_Execute($oConnection, $sQUERY, True)

	; Clean Up
	_ADO_Connection_Close($oConnection)
	$oConnection = Null

	; Display Array Content with column names as headers
	_ADO_REcordset_Display($aRecordset, 'Recordset content')

EndFunc    ;==>_Example_4_MSSQL
#EndRegion  Common / internal
